@@ -1511,9 +1511,9 @@ class JsrInlinerAdapterTest extends AsmTest {
 
     ClassFile classFile = new ClassFile(classWriter.toByteArray());
     if (classParameter.isNotCompatibleWithCurrentJdk()) {
-      assertThrows(UnsupportedClassVersionError.class, () -> classFile.newInstance());
+      assertThrows(UnsupportedClassVersionError.class, classFile::newInstance);
     } else {
-      assertDoesNotThrow(() -> classFile.newInstance());
+      assertDoesNotThrow(classFile::newInstance);
     }
   }
 
