@@ -29,6 +29,7 @@ package org.objectweb.asm;
 
 import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -59,6 +60,14 @@ class MethodVisitorTest extends AsmTest {
     assertEquals("Unsupported api 0", exception.getMessage());
   }
 
+  @Test
+  void testGetDelegate() {
+    MethodVisitor delegate = new MethodVisitor(Opcodes.ASM4) {};
+    MethodVisitor visitor = new MethodVisitor(Opcodes.ASM4, delegate) {};
+
+    assertSame(delegate, visitor.getDelegate());
+  }
+
   @Test
   void testVisitParameter_asm4Visitor() {
     MethodVisitor methodVisitor = new MethodVisitor(Opcodes.ASM4, null) {};
@@ -431,7 +440,7 @@ class MethodVisitorTest extends AsmTest {
       this.log = log;
     }
 
-    @Deprecated
+    @Deprecated(forRemoval = false)
     @Override
     public void visitMethodInsn(
         final int opcode, final String owner, final String name, final String descriptor) {
